@@ -1,5 +1,4 @@
-/* $Id: messages.h 10246 2018-02-16 21:12:42Z iulius $
- *
+/*
  * Prototypes for message and error reporting (possibly fatal).
  *
  * The canonical version of this file is maintained in the rra-c-util package,
@@ -33,8 +32,8 @@
 #ifndef INN_MESSAGES_H
 #define INN_MESSAGES_H 1
 
-#include <inn/defines.h>
 #include "inn/portable-macros.h"
+#include "inn/system.h"
 
 #include <stdarg.h>
 #include <stddef.h>
